Merge "Restricted the tap target for "All Contacts" to the "All Contacts" button alone.  DO NOT MERGE" into klp-dev
diff --git a/res/drawable/background_favorites_menu.xml b/res/drawable/background_all_contacts.xml
similarity index 86%
rename from res/drawable/background_favorites_menu.xml
rename to res/drawable/background_all_contacts.xml
index 60933fd..0d3703f 100644
--- a/res/drawable/background_favorites_menu.xml
+++ b/res/drawable/background_all_contacts.xml
@@ -18,12 +18,12 @@
 <selector xmlns:android="http://schemas.android.com/apk/res/android">
     <item android:state_pressed="false">
         <shape android:shape="rectangle" >
-            <solid android:color="@color/favorites_menu_background_color" />
+            <solid android:color="@color/all_contacts_button_color" />
         </shape>
     </item>
     <item android:state_pressed="true">
         <shape android:shape="rectangle" >
-            <solid android:color="@color/favorites_menu_pressed_color" />
+            <solid android:color="@color/all_contacts_button_pressed_color" />
         </shape>
     </item>
 </selector>
\ No newline at end of file
diff --git a/res/layout/phone_favorites_menu.xml b/res/layout/phone_favorites_menu.xml
index 5f7a5a6..387ea5b 100644
--- a/res/layout/phone_favorites_menu.xml
+++ b/res/layout/phone_favorites_menu.xml
@@ -25,8 +25,7 @@
                 android:paddingRight="@dimen/favorites_menu_padding_horizontal"
                 android:paddingTop="@dimen/favorites_menu_padding_top"
                 android:paddingBottom="@dimen/favorites_menu_padding_bottom"
-                android:background="@drawable/background_favorites_menu"
-                android:addStatesFromChildren="true"
+                android:background="@color/favorites_menu_background_color"
         >
     <TextView
             android:layout_width="wrap_content"
@@ -39,7 +38,7 @@
             android:layout_centerVertical="true"
             android:gravity="center"
         />
-    <TextView
+    <Button
             android:id="@+id/all_contacts_button"
             android:fontFamily="@string/favorites_menu_all_contacts_font_family"
             android:layout_width="wrap_content"
@@ -48,11 +47,10 @@
             android:paddingRight="@dimen/favorites_menu_padding_horizontal"
             android:text="@string/favorites_menu_all_contacts"
             android:textSize="@dimen/favorites_menu_all_contacts_text_size"
-            android:background="@color/all_contacts_button_color"
+            android:background="@drawable/background_all_contacts"
             android:textColor="@color/all_contacts_button_text_color"
             android:layout_alignParentRight="true"
             android:layout_centerVertical="true"
             android:gravity="center"
-            android:focusable="true"
         />
 </RelativeLayout>
\ No newline at end of file
diff --git a/res/values/colors.xml b/res/values/colors.xml
index 5de0e02..e6fef3f 100644
--- a/res/values/colors.xml
+++ b/res/values/colors.xml
@@ -92,11 +92,11 @@
     <!-- Background color for the "All Contacts" button in the favorites menu. -->
     <color name="all_contacts_button_color">#999999</color>
 
-    <!-- Background color for the favorites menu when pressed. -->
-    <color name="favorites_menu_pressed_color">#d6d6d6</color>
+    <!-- Background color for the "All Contacts" button in the favorites menu when pressed. -->
+    <color name="all_contacts_button_pressed_color">#808080</color>
 
     <!-- Background color for the favorites menu. -->
-    <color name="favorites_menu_background_color">#ebebeb</color>
+    <color name="favorites_menu_background_color">#eeeeee</color>
 
     <!-- Text color for the "All Contacts" button above the favorite callers -->
     <color name="all_contacts_button_text_color">#ffffff</color>
diff --git a/src/com/android/dialer/list/PhoneFavoriteFragment.java b/src/com/android/dialer/list/PhoneFavoriteFragment.java
index 79dbe8c..675a40f 100644
--- a/src/com/android/dialer/list/PhoneFavoriteFragment.java
+++ b/src/com/android/dialer/list/PhoneFavoriteFragment.java
@@ -673,12 +673,12 @@
 
     /**
      * Prepares the favorites menu which contains the static label "Speed Dial" and the
-     * "All Contacts" button.  Taps anywhere in the view take the user to "All Contacts".
-     * This emulates how the headers in Play Store work.
+     * "All Contacts" button.  Sets the onClickListener for the "All Contacts" button.
      */
     private void prepareFavoritesMenu(View favoritesMenu) {
-        // Set the onClick listener for the view to bring up the all contacts view.
-        favoritesMenu.setOnClickListener(new OnClickListener() {
+        Button allContactsButton = (Button) favoritesMenu.findViewById(R.id.all_contacts_button);
+        // Set the onClick listener for the button to bring up the all contacts view.
+        allContactsButton.setOnClickListener(new OnClickListener() {
             @Override
             public void onClick(View view) {
                 showAllContacts();